==> haskell-random-shuffle-0.0.4-282.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-8anGimmQ69d5SwSQ8lxmX9
key:                  random-shuffle-0.0.4-8anGimmQ69d5SwSQ8lxmX9
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  4469d0a8b034b1585d9ac0d30d41752e
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-8anGimmQ69d5SwSQ8lxmX9
depends:
    MonadRandom-0.6.2-KCyUQJdYxG7BHsWXhmeF14 base-4.18.2.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-shuffle-0.0.4-283-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-2nUESpKzaSL77X0xHv6XPr
key:                  random-shuffle-0.0.4-2nUESpKzaSL77X0xHv6XPr
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  85ac1cfa038444e48d5eaab85812ff97
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-2nUESpKzaSL77X0xHv6XPr
depends:
    MonadRandom-0.6.2-83df9fO2JvCGmEJ31Pqcbj base-4.18.2.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
